diff src/plugins/plugin_xep_0065.py @ 1199:96fb74a4714d

misc: fixed some typos
author Matteo Cypriani <mcy@lm7.fr>
date Mon, 15 Sep 2014 14:18:25 +0200
parents 9a85836f0d45
children f91e7028e2c3
line wrap: on
line diff
--- a/src/plugins/plugin_xep_0065.py	Tue Sep 09 22:09:51 2014 -0400
+++ b/src/plugins/plugin_xep_0065.py	Mon Sep 15 14:18:25 2014 +0200
@@ -764,10 +764,10 @@
         self.host = plugin_parent.host
 
     def _proxyDataResult(self, iq_elt):
         """Called with the informations about proxy according to XEP-0065 #4
         Params should be filled with these infos"""
         if iq_elt["type"] == "error":
-            log.warning(_("Can't determine proxy informations"))
+            log.warning(_("Can't determine proxy information"))
             return
         query_elt = iq_elt.firstChildElement()
         if query_elt.name != "query":
@@ -764,10 +764,10 @@
 
     def _proxyDataResult(self, iq_elt):
-        """Called with the informations about proxy according to XEP-0065 #4
+        """Called with the information about proxy according to XEP-0065 #4
         Params should be filled with these infos"""
         if iq_elt["type"] == "error":